==> sspse_0.5-4.tar.gz: sspse/src/posteriornbinom.h <==
#ifndef POSTERIORNBINOM_H
#define POSTERIORNBINOM_H

double dnbinom_mu(double x, double size, double mu, int give_log);

/* I define Scale-Inverse-Chi-Square distribution Y with a scale parameter "scale"
   and degrees of freedom "df" as

   Y=scale*df/X,
   where X~Chi-sq(df).
   
   Here, E[Y]=scale*df/(df-2)

   These functions evaluate the density and generate deviates from this distribution.
*/

#define dsclinvchisqboth(x,df,scale,give_log) (give_log ? (dchisq((df)*((double)(scale))/((double)(x)),df,1)+log(((double)(scale))*(df)/(double)((x)*(x)))) : (dchisq((df)*((double)(scale))/((double)(x)),df,0)*(df)*((double)(scale))/(double)((x)*(x))))

#define dsclinvchisq(x,df,scale) (dchisq((df)*((double)(scale))/((double)(x)),df,1)+log(((double)(scale))*(df)/(double)((x)*(x))))

#define rsclinvchisq(df,scale) ((scale)*(df)/(rchisq(df)))

double nbmu(int x, double mu, double sig, int give_log);
void dnbmu (int *x, double *mu, double *sig, int *n, int *give_log, double *val);
void gnbinom (int *pop,
            int *nk, 
            int *K, 
            int *n, 
            int *samplesize, int *burnin, int *interval,
            double *mu0, double *kappa0, 
            double *sigma0,  double *df0,
            int *Npi,
	    double *muproposal, 
            double *sigmaproposal, 
            int *N, int *maxN, 
            double *sample, 
	    double *ppos,
	    double *lpriorm,
            int *burnintheta,
	    int *verbose
			 );
void MHnbinom (int *Nk, int *K,
	    double *mu0, double *kappa0, 
            double *sigma0,  double *df0,
            double *muproposal, 
            double *sigmaproposal, 
            int *N, int *Npi, double *psample,
            double *musample, double *sigmasample,
            int *samplesize, int *staken, int *burnin, int *interval,
	    int *verbose
			 );
#endif /* POSTERIORNBINOM_H */

==> sspse_1.1.0-4.tar.gz: sspse/src/posteriornbinom.h <==
#ifndef POSTERIORNBINOM_H
#define POSTERIORNBINOM_H

double dnbinom_mu(double x, double size, double mu, int give_log);

/* I define Scale-Inverse-Chi-Square distribution Y with a scale parameter "scale"
   and degrees of freedom "df" as

   Y=scale*df/X,
   where X~Chi-sq(df).
   
   Here, E[Y]=scale*df/(df-2)

   These functions evaluate the density and generate deviates from this distribution.
*/

#define dsclinvchisqboth(x,df,scale,give_log) (give_log ? (dchisq((df)*((double)(scale))/((double)(x)),df,1)+log(((double)(scale))*(df)/(double)((x)*(x)))) : (dchisq((df)*((double)(scale))/((double)(x)),df,0)*(df)*((double)(scale))/(double)((x)*(x))))

#define dsclinvchisq(x,df,scale) (dchisq((df)*((double)(scale))/((double)(x)),df,1)+log(((double)(scale))*(df)/(double)((x)*(x))))

#define rsclinvchisq(df,scale) ((scale)*(df)/(rchisq(df)))

double nbmu(int x, double mu, double sig, int give_log);
void dnbmu (int *x, double *mu, double *sig, int *n, int *give_log, double *val);
void gnbinom (int *pop,
            int *nk, 
            int *K, 
            int *n, 
            int *samplesize, int *warmup, int *interval,
            double *mu0, double *kappa0, 
            double *sigma0,  double *df0,
            int *Npi,
	    double *muproposal, 
            double *sigmaproposal, 
            int *N, int *maxN, 
            double *sample, 
	    double *ppos,
	    double *lpriorm,
            int *warmuptheta,
	    int *verbose
			 );
void MHnbinom (int *Nk, int *K,
	    double *mu0, double *kappa0, 
            double *sigma0,  double *df0,
            double *muproposal, 
            double *sigmaproposal, 
            int *N, int *Npi, double *psample,
            double *musample, double *sigmasample,
            int *samplesize, int *staken, int *warmup, int *interval,
	    int *verbose
			 );
#endif /* POSTERIORNBINOM_H */
